==> 1.0.104+1.tar.gz: lib/props/UikAction.dart <==
import 'dart:convert';
import 'package:ui_sdk/generated/json/base/json_field.dart';
import 'package:ui_sdk/generated/json/uik_action_props.g.dart';

@JsonSerializable()
class UikAction {
  late UikAction_Tap tap;

  UikAction();

  factory UikAction.fromJson(Map<String, dynamic> json) =>
      $UikActionFromJson(json);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class UikAction_Tap {
  late String type;
  late UikAction_TapData data;
  late Map<String, dynamic>? values = null;

  UikAction_Tap();

  factory UikAction_Tap.fromJson(Map<String, dynamic> json) =>
      $UikAction_TapFromJson(json);

  Map<String, dynamic> toJson() => $UikAction_TapToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class UikAction_TapData {
  late String? url = null;
  late String? skuId = null;

  late String? key;
  late String? value;

  UikAction_TapData();

  factory UikAction_TapData.fromJson(Map<String, dynamic> json) =>
      $UikAction_TapDataFromJson(json);

  Map<String, dynamic> toJson() => $UikAction_TapDataToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}
//
//
// UikAction $UikActionFromJson(Map<String, dynamic> json) {
//   final UikAction uikAction = UikAction();
//   final UikAction_Tap? tap = jsonConvert.convert<UikAction_Tap>(json['tap']);
//   if (tap != null) {
//     uikAction.tap = tap;
//   }
//   return uikAction;
// }
//
// Map<String, dynamic> $UikActionToJson(UikAction entity) {
//   final Map<String, dynamic> data = <String, dynamic>{};
//   data['tap'] = entity.tap.toJson();
//   return data;
// }
//
// UikAction_Tap $UikAction_TapFromJson(Map<String, dynamic> json) {
//   final UikAction_Tap uikAction_Tap = UikAction_Tap();
//   final String? type = jsonConvert.convert<String>(json['type']);
//   if (type != null) {
//     uikAction_Tap.type = type;
//   }
//   final UikAction_TapData? data = jsonConvert.convert<UikAction_TapData>(json['data']);
//   if (data != null) {
//     uikAction_Tap.data = data;
//   }
//   return uikAction_Tap;
// }
//
// Map<String, dynamic> $UikAction_TapToJson(UikAction_Tap entity) {
//   final Map<String, dynamic> data = <String, dynamic>{};
//   data['type'] = entity.type;
//   data['data'] = entity.data.toJson();
//   return data;
// }
//
// UikAction_TapData $UikAction_TapDataFromJson(Map<String, dynamic> json) {
//   final UikAction_TapData uikAction_TapData = UikAction_TapData();
//   final String? url = jsonConvert.convert<String>(json['url']);
//   if (url != null) {
//     uikAction_TapData.url = url;
//   }
//   return uikAction_TapData;
// }
//
// Map<String, dynamic> $UikAction_TapDataToJson(UikAction_TapData entity) {
//   final Map<String, dynamic> data = <String, dynamic>{};
//   data['url'] = entity.url;
//   return data;
// }

==> 1.0.111+1.tar.gz: lib/props/UikAction.dart <==
import 'dart:convert';
import 'package:ui_sdk/generated/json/base/json_field.dart';
import 'package:ui_sdk/generated/json/uik_action_props.g.dart';

@JsonSerializable()
class UikAction {
  late UikAction_Tap tap = UikAction_Tap();

  UikAction();

  factory UikAction.fromJson(Map<String, dynamic> json) =>
      $UikActionFromJson(json);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class UikAction_Tap {
  late String type = "";
  late UikAction_TapData data;
  late Map<String, dynamic>? values = null;

  UikAction_Tap();

  factory UikAction_Tap.fromJson(Map<String, dynamic> json) =>
      $UikAction_TapFromJson(json);

  Map<String, dynamic> toJson() => $UikAction_TapToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}

@JsonSerializable()
class UikAction_TapData {
  late String? url = null;
  late String? skuId = null;

  late String? key;
  late String? value;

  UikAction_TapData();

  factory UikAction_TapData.fromJson(Map<String, dynamic> json) =>
      $UikAction_TapDataFromJson(json);

  Map<String, dynamic> toJson() => $UikAction_TapDataToJson(this);

  @override
  String toString() {
    return jsonEncode(this);
  }
}
//
//
// UikAction $UikActionFromJson(Map<String, dynamic> json) {
//   final UikAction uikAction = UikAction();
//   final UikAction_Tap? tap = jsonConvert.convert<UikAction_Tap>(json['tap']);
//   if (tap != null) {
//     uikAction.tap = tap;
//   }
//   return uikAction;
// }
//
// Map<String, dynamic> $UikActionToJson(UikAction entity) {
//   final Map<String, dynamic> data = <String, dynamic>{};
//   data['tap'] = entity.tap.toJson();
//   return data;
// }
//
// UikAction_Tap $UikAction_TapFromJson(Map<String, dynamic> json) {
//   final UikAction_Tap uikAction_Tap = UikAction_Tap();
//   final String? type = jsonConvert.convert<String>(json['type']);
//   if (type != null) {
//     uikAction_Tap.type = type;
//   }
//   final UikAction_TapData? data = jsonConvert.convert<UikAction_TapData>(json['data']);
//   if (data != null) {
//     uikAction_Tap.data = data;
//   }
//   return uikAction_Tap;
// }
//
// Map<String, dynamic> $UikAction_TapToJson(UikAction_Tap entity) {
//   final Map<String, dynamic> data = <String, dynamic>{};
//   data['type'] = entity.type;
//   data['data'] = entity.data.toJson();
//   return data;
// }
//
// UikAction_TapData $UikAction_TapDataFromJson(Map<String, dynamic> json) {
//   final UikAction_TapData uikAction_TapData = UikAction_TapData();
//   final String? url = jsonConvert.convert<String>(json['url']);
//   if (url != null) {
//     uikAction_TapData.url = url;
//   }
//   return uikAction_TapData;
// }
//
// Map<String, dynamic> $UikAction_TapDataToJson(UikAction_TapData entity) {
//   final Map<String, dynamic> data = <String, dynamic>{};
//   data['url'] = entity.url;
//   return data;
// }
